@@ -1,15 +1,13 @@
 from .categorical_categorical import (
-    mat_fisher_naive,
     fisher_arr,
     mat_fisher,
+    mat_fisher_naive,
     mat_fisher_nan,
 )
-
-from .continuous_categorical import mat_mwu_naive, mat_mwu
-
+from .continuous_categorical import mat_mwu, mat_mwu_gpu, mat_mwu_naive
 from .continuous_continuous import (
-    mat_corr_naive,
     mat_corr,
+    mat_corr_naive,
     mat_corr_nan,
     mat_corr_subtyped,
 )
